@@ -602,12 +602,13 @@ func (k *Kmdt) CmdLoop(ctx context.Context, intro string) {
 				var err error
 				line, err = k.linecore.Readline()
 				if err == readline.ErrInterrupt {
-					break // Exit
-					// Old code left as example.
-					// Clearing the line requires changes to readline.
-					//if len(line) == 0 { // Blank line, exit.
-					//} else { // Filled line, clear.
-					//}
+					p, err := os.FindProcess(os.Getpid())
+					if err != nil {
+						continue
+					}
+					if err := p.Signal(os.Interrupt); err != nil {
+						continue
+					}
 				} else if err == io.EOF {
 					k.log(DEEPDEBUG, "KMDT readline EOF")
 					line = "EOF"
